# AUTOMATICALLY GENERATED by `shtab`



complete vcspull \
        'c/--/(all color detailed dry-run exit-on-error fetch file help json log-level long max-concurrent ndjson no-concurrent offline path recursive relative-paths sequential show-unchanged summary-only tree verbose version workspace workspace-root write yes)/' \
        'c/-/(- V d f h n r v w x y)/' \
        'n/-f/f/' \
        'n/--file/f/' \
        'n/--color/(auto always never)/' \
        'n/--color/(auto always never)/' \
        'n/--color/(auto always never)/' \
        'p/1/(sync list status add discover fmt)/' \
        'p@2@`set cmd=($COMMAND_LINE); `@' \
        'p/*/()/'
